@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::GenericInterface::Transport::HTTP::Test;
@@ -15,43 +15,25 @@ use HTTP::Request::Common;
 use LWP::UserAgent;
 use LWP::Protocol;
 
-use Kernel::System::Web::Request;
+# prevent 'Used once' warning for Kernel::OM
+use Kernel::System::ObjectManager;
+
+our $ObjectManagerDisabled = 1;
 
 =head1 NAME
 
-Kernel::GenericInterface::Transport::Test - GenericInterface network transport interface for testing purposes
-
-=head1 SYNOPSIS
+Kernel::GenericInterface::Transport::HTTP::Test - GenericInterface network transport interface for testing purposes
 
 =head1 PUBLIC INTERFACE
 
-=over 4
-
-=item new()
+=head2 new()
 
 usually, you want to create an instance of this
 by using Kernel::GenericInterface::Transport->new();
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
     use Kernel::GenericInterface::Transport;
 
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
     my $TransportObject = Kernel::GenericInterface::Transport->new(
-        ConfigObject       => $ConfigObject,
-        LogObject          => $LogObject,
-        DBObject           => $DBObject,
-        MainObject         => $MainObject,
-        TimeObject         => $TimeObject,
-        EncodeObject       => $EncodeObject,
 
         TransportConfig => {
             Type => 'HTTP::Test',
@@ -74,10 +56,7 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    for my $Needed (
-        qw(LogObject EncodeObject ConfigObject MainObject DebuggerObject TransportConfig)
-        )
-    {
+    for my $Needed (qw( DebuggerObject TransportConfig)) {
         $Self->{$Needed} = $Param{$Needed} || return {
             Success      => 0,
             ErrorMessage => "Got no $Needed!"
@@ -87,7 +66,7 @@ sub new {
     return $Self;
 }
 
-=item ProviderProcessRequest()
+=head2 ProviderProcessRequest()
 
 this will read the incoming HTTP request via CGI and
 return the HTTP parameters in the data hash.
@@ -98,6 +77,7 @@ sub ProviderProcessRequest {
     my ( $Self, %Param ) = @_;
 
     if ( $Self->{TransportConfig}->{Config}->{Fail} ) {
+
         return {
             Success      => 0,
             ErrorMessage => "HTTP status code: 500",
@@ -105,7 +85,7 @@ sub ProviderProcessRequest {
         };
     }
 
-    my $ParamObject = Kernel::System::Web::Request->new( %{$Self} );
+    my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
 
     my %Result;
     for my $ParamName ( $ParamObject->GetParamNames() ) {
@@ -118,6 +98,7 @@ sub ProviderProcessRequest {
     }
 
     if ( !%Result ) {
+
         return $Self->{DebuggerObject}->Error(
             Summary => 'No request data found.',
         );
@@ -130,7 +111,7 @@ sub ProviderProcessRequest {
     };
 }
 
-=item ProviderGenerateResponse()
+=head2 ProviderGenerateResponse()
 
 this will generate a query string from the passed data hash
 and generate an HTTP response with this string as the body.
@@ -143,6 +124,7 @@ sub ProviderGenerateResponse {
     my ( $Self, %Param ) = @_;
 
     if ( $Self->{TransportConfig}->{Config}->{Fail} ) {
+
         return {
             Success      => 0,
             ErrorMessage => 'Test response generation failed',
@@ -182,7 +164,7 @@ sub ProviderGenerateResponse {
     };
 }
 
-=item RequesterPerformRequest()
+=head2 RequesterPerformRequest()
 
 in Fail mode, returns error status. Otherwise, returns the
 query string generated out of the data for the HTTP response.
@@ -209,6 +191,7 @@ sub RequesterPerformRequest {
     my ( $Self, %Param ) = @_;
 
     if ( $Self->{TransportConfig}->{Config}->{Fail} ) {
+
         return {
             Success      => 0,
             ErrorMessage => "HTTP status code: 500",
@@ -231,8 +214,6 @@ sub RequesterPerformRequest {
     };
 }
 
-=back
-
 =begin Internal:
 
 =cut
@@ -241,7 +222,7 @@ sub RequesterPerformRequest {
 
 Kernel::GenericInterface::Transport::HTTP::Test::CustomHTTPProtocol
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 This package is used to handle the custom HTTP requests of
 Kernel::GenericInterface::Transport::HTTP::Test.
@@ -250,9 +231,9 @@ sending them out to the network.
 
 =cut
 
-package Kernel::GenericInterface::Transport::HTTP::Test::CustomHTTPProtocol;
+package Kernel::GenericInterface::Transport::HTTP::Test::CustomHTTPProtocol;    ## no critic
 
-use base qw(LWP::Protocol);
+use parent qw(LWP::Protocol);
 
 sub new {
     my $Class = shift;
@@ -260,7 +241,7 @@ sub new {
     return $Class->SUPER::new(@_);
 }
 
-sub request {    ## no critic
+sub request {                                                                   ## no critic
     my $Self = shift;
 
     my ( $Request, $Proxy, $Arg, $Size, $Timeout ) = @_;
@@ -283,10 +264,10 @@ sub request {    ## no critic
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
