@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -11,7 +11,7 @@ package Kernel::System::Console::Command::Dev::Tools::ConsoleStats;
 use strict;
 use warnings;
 
-use base qw(Kernel::System::Console::BaseCommand Kernel::System::Console::Command::List);
+use parent qw(Kernel::System::Console::BaseCommand Kernel::System::Console::Command::List);
 
 our @ObjectDependencies = (
 );
