@@ -1,21 +1,19 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU AFFERO General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
-# any later version.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-# or see http://www.gnu.org/licenses/agpl.txt.
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 use strict;
@@ -489,8 +487,8 @@ my @NeededModules = (
     },
     {
         Module    => 'XML::LibXML',
-        Required  => 0,
-        Comment   => 'Required for Generic Interface XSLT mapping module.',
+        Required  => 1,
+        Comment   => 'Required for XML processing.',
         InstTypes => {
             aptget => 'libxml-libxml-perl',
             zypper => 'perl-XML-LibXML',
@@ -510,7 +508,7 @@ my @NeededModules = (
     {
         Module    => 'XML::Parser',
         Required  => 0,
-        Comment   => 'Recommended for faster xml handling.',
+        Comment   => 'Recommended for XML processing.',
         InstTypes => {
             aptget => 'libxml-parser-perl',
             emerge => 'dev-perl/XML-Parser',
@@ -521,7 +519,7 @@ my @NeededModules = (
     {
         Module    => 'YAML::XS',
         Required  => 1,
-        Comment   => 'Very important',
+        Comment   => 'Required for fast YAML processing.',
         InstTypes => {
             aptget => 'libyaml-libyaml-perl',
             emerge => 'dev-perl/YAML-LibYAML',
