@@ -1,9 +1,9 @@
 // --
-// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (AGPL). If you
-// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+// the enclosed file COPYING for license information (GPL). If you
+// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 // --
 
 "use strict";
@@ -34,6 +34,7 @@ Core.Customer.TicketZoom = (function (TargetNS) {
      */
     function CalculateHeight(Iframe){
         Iframe = isJQueryObject(Iframe) ? Iframe.get(0) : Iframe;
+
         setTimeout(function () {
             var $IframeContent = $(Iframe.contentDocument || Iframe.contentWindow.document),
                 NewHeight = $IframeContent.height();
@@ -62,13 +63,11 @@ Core.Customer.TicketZoom = (function (TargetNS) {
      *      Resizes Iframe to its max inner height and (optionally) calls callback.
      */
     function ResizeIframe(Iframe, Callback){
-        // initial height calculation
-        $(Iframe).attr('onload', function() {
-            CalculateHeight(this);
-            if ($.isFunction(Callback)) {
-                Callback();
-            }
-        });
+        Iframe = isJQueryObject(Iframe) ? Iframe.get(0) : Iframe;
+        CalculateHeight(Iframe);
+        if ($.isFunction(Callback)) {
+            Callback();
+        }
     }
 
     /**
@@ -85,16 +84,18 @@ Core.Customer.TicketZoom = (function (TargetNS) {
     function CheckIframe(Iframe, Callback){
         var Source;
 
+        Iframe = isJQueryObject(Iframe) ? Iframe.get(0) : Iframe;
+
         if ($.browser.safari || $.browser.opera){
-            $(Iframe).load(function(){
-                setTimeout(ResizeIframe, 0, this, Callback);
+            $(Iframe).on('load', function() {
+                setTimeout(ResizeIframe, 0, Iframe, Callback);
             });
             Source = Iframe.src;
             Iframe.src = '';
             Iframe.src = Source;
         }
         else {
-            $(Iframe).load(function(){
+            $(Iframe).on('load', function() {
                 ResizeIframe(this, Callback);
             });
         }
@@ -106,13 +107,12 @@ Core.Customer.TicketZoom = (function (TargetNS) {
      * @memberof Core.Customer.TicketZoom
      * @function
      * @param {jQueryObject} $Message
-     * @param {jQueryObject} $Status
      * @description
      *      This function is called when an articles should be loaded. Our trick is, to hide the
      *      url of a containing iframe in the title attribute of the iframe so that it doesn't load
      *      immediately when the site loads. So we set the url in this function.
      */
-    function LoadMessage($Message, $Status){
+    function LoadMessage($Message){
         var $SubjectHolder = $('h3 span', $Message),
             Subject = $SubjectHolder.text(),
             LoadingString = $SubjectHolder.attr('title'),
@@ -128,11 +128,8 @@ Core.Customer.TicketZoom = (function (TargetNS) {
         }
 
         function Callback(){
-            /*  Set StateStorage to true */
-            $Status.val('true');
-
-            /*  Show MessageContent -> add class Visible */
-            $Message.addClass('Visible');
+            /*  Set data-articlestate to true and add class Visible */
+            $Message.attr('data-articlestate', "true").addClass('Visible');
 
             /*  Change Subject back from Loading */
             $SubjectHolder.text(Subject).attr('title', Subject);
@@ -153,7 +150,7 @@ Core.Customer.TicketZoom = (function (TargetNS) {
      * @function
      * @param {jQueryObject} $Message
      * @description
-     *      This function checks the value of a hidden input field containing the state of the article:
+     *      This function checks the value of data-articlestate attribute containing the state of the article:
      *      untouched (= not yet loaded), true or false. If the article is already loaded (-> true), and
      *      user calls this function by clicking on the message head, the article gets hidden by removing
      *      the class 'Visible' and the status changes to false. If the message head is clicked while the
@@ -161,18 +158,17 @@ Core.Customer.TicketZoom = (function (TargetNS) {
      *      the status gets changed to true.
      */
     function ToggleMessage($Message){
-        var $Status = $('> input[name=ArticleState]', $Message);
-        switch ($Status.val()){
+        switch ($Message.attr('data-articlestate')) {
             case "untouched":
-                LoadMessage($Message, $Status);
+                LoadMessage($Message);
             break;
             case "true":
                 $Message.removeClass('Visible');
-                $Status.val("false");
+                $Message.attr('data-articlestate', "false");
             break;
             case "false":
                 $Message.addClass('Visible');
-                $Status.val("true");
+                $Message.attr('data-articlestate', "true");
             break;
         }
     }
@@ -185,48 +181,45 @@ Core.Customer.TicketZoom = (function (TargetNS) {
      *      This function binds functions to the 'MessageHeader' and the 'Reply' button
      *      to toggle the visibility of the MessageBody and the reply form.
      *      Also it checks the iframes to re-size them to their full (inner) size
-     *      and hides the quotes inside the iframes + adds an anchor to toggle the visibility of the quotes
+     *      and hides the quotes inside the iframes + adds an anchor to toggle the visibility of the quotes.
+     *      Furthermore it execute field updates, add and remove of attachments.
      */
     TargetNS.Init = function(){
-        var $Messages = $('#Messages > li'),
-            $VisibleIframe = $('.VisibleFrame'),
-            $MessageHeaders = $('.MessageHeader', $Messages),
+        var $VisibleIframe = $('.VisibleFrame'),
             $FollowUp = $('#FollowUp'),
             $RTE = $('#RichText'),
-            ZoomExpand = $('#ZoomExpand').val();
+            ZoomExpand = $('#ZoomExpand').val(),
+            $Form,
+            FieldID,
+            DynamicFieldNames = Core.Config.Get('DynamicFieldNames');
 
-        $MessageHeaders.click(function(Event){
+        $('#Messages > li > .MessageHeader').on('click', function(Event){
             ToggleMessage($(this).parent());
             Event.preventDefault();
         });
-        $('#ReplyButton').click(function(Event){
+        $('#ReplyButton').on('click', function(Event){
             Event.preventDefault();
             $FollowUp.addClass('Visible');
             $('html').css({scrollTop: $('#Body').height()});
             Core.UI.RichTextEditor.Focus($RTE);
         });
-        $('#CloseButton').click(function(Event){
+        $('#CloseButton').on('click', function(Event){
             Event.preventDefault();
             $FollowUp.removeClass('Visible');
             $('html').css({scrollTop: $('#Body').height()});
         });
         /* Set statuses saved in the hidden fields for all visible messages if ZoomExpand is present */
         if (!ZoomExpand || isNaN(ZoomExpand)) {
-            $('> input[name=ArticleState]', $Messages).val("true");
+            $('#Messages > li').attr('data-articlestate', "true");
             ResizeIframe($VisibleIframe);
         }
         else {
             /* Set statuses saved in the hidden fields for all messages */
-            $('#Messages > li:not(:last)').find('input[name=ArticleState]').val("untouched");
-            $('#Messages > li:last').find('input[name=ArticleState]').val("true");
+            $('#Messages > li:not(:last)').attr('data-articlestate', "untouched");
+            $('#Messages > li:last').attr('data-articlestate', "true");
             ResizeIframe($VisibleIframe.get(0));
         }
 
-        // add switchable toggle
-        $('div.Label.Switchable').off('click.Switch').on('click.Switch', function() {
-            $(this).next('span').find('.Switch').toggleClass('Hidden');
-        });
-
         // init browser link message close button
         if ($('.MessageBrowser').length) {
             $('.MessageBrowser a.Close').on('click', function () {
@@ -248,7 +241,40 @@ Core.Customer.TicketZoom = (function (TargetNS) {
                 return false;
             });
         }
+
+        // Bind event to State field.
+        $('#StateID').on('change', function () {
+            Core.AJAX.FormUpdate($('#ReplyCustomerTicket'), 'AJAXUpdate', 'StateID', ['PriorityID', 'TicketID'].concat(DynamicFieldNames));
+        });
+
+        // Bind event to Priority field.
+        $('#PriorityID').on('change', function () {
+            Core.AJAX.FormUpdate($('#ReplyCustomerTicket'), 'AJAXUpdate', 'PriorityID', ['StateID', 'TicketID'].concat(DynamicFieldNames));
+        });
+
+        // Bind event to AttachmentUpload button.
+        $('#Attachment').on('change', function () {
+            var $Form = $('#Attachment').closest('form');
+            Core.Form.Validate.DisableValidation($Form);
+            $Form.find('#AttachmentUpload').val('1').end().submit();
+        });
+
+        // Bind event to AttachmentDelete button.
+        $('button[id*=AttachmentDeleteButton]').on('click', function () {
+            $Form = $(this).closest('form');
+            FieldID = $(this).attr('id').split('AttachmentDeleteButton')[1];
+            $('#AttachmentDelete' + FieldID).val(1);
+            Core.Form.Validate.DisableValidation($Form);
+            $Form.trigger('submit');
+        });
+
+        $('a.AsPopup').on('click', function () {
+            Core.UI.Popup.OpenPopup($(this).attr('href'), 'TicketAction');
+            return false;
+        });
     };
 
+    Core.Init.RegisterNamespace(TargetNS, 'APP_MODULE');
+
     return TargetNS;
 }(Core.Customer.TicketZoom || {}));
